#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 criterion
version:              1.6.3.0
visibility:           public
id:                   criterion-1.6.3.0-DFjSrhHOfCRHgw3XagpODT
key:                  criterion-1.6.3.0-DFjSrhHOfCRHgw3XagpODT
license:              BSD-3-Clause
copyright:            2009-2016 Bryan O'\''Sullivan and others
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             http://www.serpentine.com/criterion
synopsis:             Robust, reliable performance measurement and analysis
description:
    This library provides a powerful but simple way to measure software
    performance.  It provides both a framework for executing and
    analysing benchmarks and a set of driver functions that makes it
    easy to build and run benchmarks, and to analyse their results.

    The fastest way to get started is to read the
    <http://www.serpentine.com/criterion/tutorial.html online tutorial>,
    followed by the documentation and examples in the "Criterion.Main"
    module.

    For examples of the kinds of reports that criterion generates, see
    <http://www.serpentine.com/criterion the home page>.

category:             Development, Performance, Testing, Benchmarking
abi:                  1d9c2d5f93a70dfb63fe120e01245fdc
exposed:              True
exposed-modules:
    Criterion Criterion.Analysis Criterion.IO Criterion.IO.Printf
    Criterion.Internal Criterion.Main Criterion.Main.Options
    Criterion.Monad Criterion.Report Criterion.Types

hidden-modules:       Criterion.Monad.Internal Paths_criterion
import-dirs:          /usr/lib/ghc-9.6.6/site-local/criterion-1.6.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/criterion-1.6.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/criterion-1.6.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-criterion
hs-libraries:         HScriterion-1.6.3.0-DFjSrhHOfCRHgw3XagpODT
depends:
    Glob-0.10.2-85huPVQ78toBRD8Sm7F5mN
    aeson-2.2.2.0-D5UyU4s17IF6uKIJTSur7o base-4.18.2.1
    base-compat-batteries-0.14.1-A247tuKc9iJADh9oFAWHwc binary-0.8.9.1
    binary-orphans-1.0.5.1-2ogJPGMUYfXFMscELgasTo bytestring-0.11.5.3
    cassava-0.5.4.1-BmohHwtb7uE93FFOI4JzTr
    code-page-0.2.1-8r7bPp8D9hK7XmJl89SAkA containers-0.6.7
    criterion-measurement-0.2.4.0-3pAVMS2YzGVFNiibOFuBCz
    deepseq-1.4.8.1 directory-1.3.8.5 exceptions-0.10.7
    filepath-1.4.300.1 js-chart-2.9.4.1-Es3f7aYy6XKGmoiCGVJgsO
    microstache-1.0.3-BFvBNMoAnZYH906f4MiIky mtl-2.3.1
    mwc-random-0.15.3.0-IfQtt58wkqEEr5VCXSr81F
    optparse-applicative-0.18.1.0-6cREMRvcEOW6x5IeiCw6lt
    parsec-3.1.16.1 prettyprinter-1.7.1-4EZkWc5tq0yFCEPbAPD9Qw
    prettyprinter-ansi-terminal-1.1.4-Hjmzev0gSkeIf1zTaF3b5Y
    statistics-0.16.4.0-2ZzsQS4HA3GG9xm3J1glm4 text-2.0.2 time-1.12.2
    transformers-0.6.1.0
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH
    vector-0.13.2.0-EFjd2WQg5nEG5BmM55CoiV
    vector-algorithms-0.9.1.0-4GCzSOVusitI00BCra3ad4

haddock-interfaces:   /usr/share/doc/haskell-criterion/html/criterion.haddock
haddock-html:         /usr/share/doc/haskell-criterion/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

